Function scip::write_message_to_file
source · pub fn write_message_to_file<P>(
path: P,
msg: impl Message
) -> Result<(), Box<dyn Error>>Expand description
Write a message to a particular filepath.
This allows users of the SCIP library to not add protobuf as a direct dependency of the project (which can be useful to limit usage of protobuf elsewhere if not desired).